[PATCH] D25710: [Doc] Drop MSVC2013 support

Reid Kleckner via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Thu Dec 15 11:18:29 PST 2016


This revision was automatically updated to reflect the committed changes.
Closed by commit rL289854: Fix some remaining documentation references to MSVC 2013 (authored by rnk).

Changed prior to commit:
  https://reviews.llvm.org/D25710?vs=75161&id=81626#toc

Repository:
  rL LLVM

https://reviews.llvm.org/D25710

Files:
  llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
  llvm/trunk/docs/CodingStandards.rst
  llvm/trunk/docs/GettingStarted.rst


Index: llvm/trunk/docs/CodingStandards.rst
===================================================================
--- llvm/trunk/docs/CodingStandards.rst
+++ llvm/trunk/docs/CodingStandards.rst
@@ -131,9 +131,8 @@
 * Delegating constructors: N1986_
 * Default member initializers (non-static data member initializers): N2756_
 
-  * Only use these for scalar members that would otherwise be left
-    uninitialized. Non-scalar members generally have appropriate default
-    constructors.
+  * Feel free to use these wherever they make sense and where the `=`
+    syntax is allowed. Don't use braced initialization syntax.
 
 .. _N2118: http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2006/n2118.html
 .. _N2439: http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2007/n2439.htm
Index: llvm/trunk/docs/GettingStarted.rst
===================================================================
--- llvm/trunk/docs/GettingStarted.rst
+++ llvm/trunk/docs/GettingStarted.rst
@@ -262,7 +262,7 @@
 
 * Clang 3.1
 * GCC 4.8
-* Visual Studio 2015
+* Visual Studio 2015 (Update 3)
 
 Anything older than these toolchains *may* work, but will require forcing the
 build system with a special option and is not really a supported host platform.
Index: llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
===================================================================
--- llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
+++ llvm/trunk/cmake/modules/CheckCompilerVersion.cmake
@@ -1,5 +1,5 @@
 # Check if the host compiler is new enough. LLVM requires at least GCC 4.8,
 # MSVC 2013, or Clang 3.1.
 
 include(CheckCXXSourceCompiles)
 
@@ -17,8 +17,8 @@
       endif()
 
       if (CMAKE_CXX_SIMULATE_ID MATCHES "MSVC")
-        if (CMAKE_CXX_SIMULATE_VERSION VERSION_LESS 18.0)
-          message(FATAL_ERROR "Host Clang must have at least -fms-compatibility-version=18.0")
+        if (CMAKE_CXX_SIMULATE_VERSION VERSION_LESS 19.0)
+          message(FATAL_ERROR "Host Clang must have at least -fms-compatibility-version=19.0")
         endif()
         set(CLANG_CL 1)
       elseif(NOT LLVM_ENABLE_LIBCXX)
@@ -41,10 +41,10 @@
         set(CMAKE_REQUIRED_LIBRARIES ${OLD_CMAKE_REQUIRED_LIBRARIES})
       endif()
     elseif(CMAKE_CXX_COMPILER_ID MATCHES "MSVC")
-      if(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 18.0)
-        message(FATAL_ERROR "Host Visual Studio must be at least 2013")
-      elseif(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 18.0.31101)
-        message(WARNING "Host Visual Studio should at least be 2013 Update 4 (MSVC 18.0.31101)"
+      if(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 19.0)
+        message(FATAL_ERROR "Host Visual Studio must be at least 2015")
+      elseif(CMAKE_CXX_COMPILER_VERSION VERSION_LESS 19.00.24215.1)
+        message(WARNING "Host Visual Studio should at least be 2015 Update 3 (MSVC 19.00.24215.1)"
           "  due to miscompiles from earlier versions")
       endif()
     endif()


-------------- next part --------------
@@ -1,5 +1,5 @@
 # Check if the host compiler is new enough. LLVM requires at least GCC 4.8,
-# MSVC 2013, or Clang 3.1.
+# MSVC 2015 (Update 3), or Clang 3.1.
 
 include(CheckCXXSourceCompiles)
A non-text attachment was scrubbed...
Name: D25710.81626.patch
Type: text/x-patch
Size: 2972 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20161215/525b93ee/attachment.bin>


More information about the llvm-commits mailing list